@@ -6,7 +6,7 @@ bayesglm <- function (formula, family = gaussian, data, weights, subset,
   prior.mean.for.intercept = 0,
   prior.scale.for.intercept = NULL, prior.df.for.intercept = 1,
   min.prior.scale = 1e-12, scaled = TRUE, keep.order = TRUE,
-  drop.baseline = TRUE, n.iter = 100, 
+  drop.baseline = TRUE, n.iter = 100,
   print.unnormalized.log.posterior = FALSE, Warning=TRUE,...)
 {
   call <- match.call()
@@ -24,7 +24,7 @@ bayesglm <- function (formula, family = gaussian, data, weights, subset,
     data <- environment(formula)
   }
   mf <- match.call(expand.dots = FALSE)
-  m <- match(c("formula", "data", "subset", "weights", "na.action", 
+  m <- match(c("formula", "data", "subset", "weights", "na.action",
     "etastart", "mustart", "offset"), names(mf), 0L)
   mf <- mf[c(1L, m)]
   mf$drop.unused.levels <- drop.unused.levels
@@ -32,14 +32,14 @@ bayesglm <- function (formula, family = gaussian, data, weights, subset,
   mf[[1L]] <- quote(stats::model.frame)
   mf <- eval(mf, parent.frame())
   #switch(method, model.frame = return(mf), glm.fit = 1, stop("invalid 'method': ", method))
-  if (identical(method, "model.frame")) 
+  if (identical(method, "model.frame"))
     return(mf)
-  if (!is.character(method) && !is.function(method)) 
+  if (!is.character(method) && !is.function(method))
     stop("invalid 'method' argument")
-  if (identical(method, "glm.fit")) 
+  if (identical(method, "glm.fit"))
     control <- do.call("glm.control", control)
   mt <- attr(mf, "terms")
-    
+
   Y <- model.response(mf, "any")
   if (length(dim(Y)) == 1) {
     nm <- rownames(Y)
@@ -67,8 +67,8 @@ bayesglm <- function (formula, family = gaussian, data, weights, subset,
   offset <- as.vector(model.offset(mf))
 
   if (!is.null(offset)) {
-    if (length(offset) != NROW(Y)) 
-      stop(gettextf("number of offsets is %d should equal %d (number of observations)", 
+    if (length(offset) != NROW(Y))
+      stop(gettextf("number of offsets is %d should equal %d (number of observations)",
                 length(offset), NROW(Y)), domain = NA)
   }
   mustart <- model.extract(mf, "mustart")
@@ -78,26 +78,26 @@ bayesglm <- function (formula, family = gaussian, data, weights, subset,
   fit <- bayesglm.fit(x = X, y = Y, weights = weights, start = start,
     etastart = etastart, mustart = mustart, offset = offset,
     family = family, control = glm.control(maxit = n.iter),
-    intercept = attr(mt, "intercept") > 0L, 
+    intercept = attr(mt, "intercept") > 0L,
     prior.mean = prior.mean,
-    prior.scale = prior.scale, prior.df = prior.df, 
+    prior.scale = prior.scale, prior.df = prior.df,
     prior.mean.for.intercept = prior.mean.for.intercept,
     prior.scale.for.intercept = prior.scale.for.intercept,
-    prior.df.for.intercept = prior.df.for.intercept, 
+    prior.df.for.intercept = prior.df.for.intercept,
     min.prior.scale = min.prior.scale, scaled = scaled, Warning=Warning)
   if (length(offset) && attr(mt, "intercept") > 0L) {
    cat("bayesglm not yet set up to do deviance comparion here\n")
-  fit$null.deviance <- bayesglm.fit(x = X[, "(Intercept)", drop = FALSE], y = Y, weights = weights, 
-            offset = offset, family = family, control = control, 
-            intercept = TRUE, 
+  fit$null.deviance <- bayesglm.fit(x = X[, "(Intercept)", drop = FALSE], y = Y, weights = weights,
+            offset = offset, family = family, control = control,
+            intercept = TRUE,
             prior.mean = prior.mean,
-            prior.scale = prior.scale, prior.df = prior.df, 
+            prior.scale = prior.scale, prior.df = prior.df,
             prior.mean.for.intercept = prior.mean.for.intercept,
             prior.scale.for.intercept = prior.scale.for.intercept,
-            prior.df.for.intercept = prior.df.for.intercept, 
+            prior.df.for.intercept = prior.df.for.intercept,
             min.prior.scale = min.prior.scale, scaled = scaled, Warning=Warning)$deviance
   }
-  
+
   if (model){
     fit$model <- mf
   }
@@ -116,9 +116,9 @@ bayesglm <- function (formula, family = gaussian, data, weights, subset,
   class(fit) <- c("bayesglm", "glm", "lm")
   return(fit)
 }
-  
-bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL, 
-        etastart = NULL, mustart = NULL, offset = rep(0, nobs), 
+
+bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
+        etastart = NULL, mustart = NULL, offset = rep(0, nobs),
         family = gaussian(),
         control = glm.control(), intercept = TRUE,
         prior.mean = 0,
@@ -134,33 +134,33 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
     nobs <- NROW(y)
     nvars <- NCOL(x)
     conv <- FALSE
-    EMPTY <- nvars == 0  
+    EMPTY <- nvars == 0
 
-    output <- .bayesglm.fit.initialize.priors (family, prior.scale, prior.scale.for.intercept, nvars, 
+    output <- .bayesglm.fit.initialize.priors (family, prior.scale, prior.scale.for.intercept, nvars,
             prior.mean, prior.mean.for.intercept, intercept, prior.df, prior.df.for.intercept)
-    prior.scale <- output$prior.scale 
+    prior.scale <- output$prior.scale
     prior.scale.for.intercept <- output$prior.scale.for.intercept
     prior.mean <- output$prior.mean
     prior.mean.for.intercept <- output$prior.mean.for.intercept
     prior.df <- output$prior.df
     prior.df.for.intercept <- output$prior.df.for.intercept
-    
+
     prior.scale <- .bayesglm.fit.initialize.priorScale (scaled, family, prior.scale, y, nvars, x, min.prior.scale)
-   
+
     output <- .bayesglm.fit.initialize.x (x, nvars, nobs, intercept, scaled)
     x <- output$x
     xnames <- output$xnames
     x.nobs <- output$x.nobs
-    
+
     output <- .bayesglm.fit.initialize.other (nobs, y, weights, offset)
     ynames <- output$ynames
     weights <- output$weights
     offset <- output$offset
-    
+
     family <- .bayesglm.fit.initialize.family (family)
     ## TODO: DL -- I would put this inside initialize.family, but this does some magic setting of variables.
     ##             What I can do is push an environment into the function and wrap it in.
-    
+
     if (is.null(mustart)){
         eval(family$initialize)
     }
@@ -189,8 +189,8 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
     }
     else {
         ## 3.1 ##
-        output <- .bayesglm.fit.loop.setup (etastart, start = start, nvars, xnames, offset, x, nobs, family, 
-                mustart, eta, weights, conv, prior.scale, y, x.nobs) 
+        output <- .bayesglm.fit.loop.setup (etastart, start = start, nvars, xnames, offset, x, nobs, family,
+                mustart, eta, weights, conv, prior.scale, y, x.nobs)
         coefold <- output$Coefold
         start <- output$Start
         eta <- output$eta
@@ -201,17 +201,17 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
         dispersion <- output$dispersion
         dispersionold <- output$dispersionold
         ##########
-        
+
         ## 3.2 ## check the link between 3.1 and 3.2
         output.new <- .bayesglm.fit.loop.main.ideal (control, x, y, nvars, nobs, weights, offset,
-                intercept, scaled, 
+                intercept, scaled,
                 start = start, etastart = eta, mustart = mu,
                 family,
                 prior.mean, prior.mean.for.intercept, prior.scale, prior.df, prior.df.for.intercept,
                 print.unnormalized.log.posterior,
                 Warning)
         fit <- output.new$fit
-        
+
         good <- output.new$good
         z <- output.new$z
         w <- output.new$w
@@ -233,15 +233,15 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
 
     ## 4 ##
     output <- .bayesglm.fit.cleanup (
-      ynames = ynames, 
-      residuals = residuals, 
-      mu = mu, eta = eta, nobs = nobs, 
-      wt= weights, w = w, good = good, 
-      linkinv = family$linkinv, 
-      dev.resids = family$dev.resids, 
-      y = y, 
-      intercept = intercept, 
-      fit = fit, offset = offset, EMPTY = EMPTY, 
+      ynames = ynames,
+      residuals = residuals,
+      mu = mu, eta = eta, nobs = nobs,
+      wt= weights, w = w, good = good,
+      linkinv = family$linkinv,
+      dev.resids = family$dev.resids,
+      y = y,
+      intercept = intercept,
+      fit = fit, offset = offset, EMPTY = EMPTY,
       dev =dev, aic = family$aic
       )
 
@@ -261,37 +261,37 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
     resdf <- output$resdf
     aic.model <- output$aic.model
     #######
-    list(coefficients = coef, 
-            residuals = residuals, 
+    list(coefficients = coef,
+            residuals = residuals,
             fitted.values = mu,
-            effects = if (!EMPTY) fit$effects, 
+            effects = if (!EMPTY) fit$effects,
             R = if (!EMPTY) Rmat,
-            rank = rank, 
-            qr = if (!EMPTY) structure(getQr(fit)[c("qr", "rank", "qraux", "pivot", "tol")], class = "qr"), 
+            rank = rank,
+            qr = if (!EMPTY) structure(getQr(fit)[c("qr", "rank", "qraux", "pivot", "tol")], class = "qr"),
             family = family,
-            linear.predictors = eta, 
-            deviance = dev, 
+            linear.predictors = eta,
+            deviance = dev,
             aic = aic.model,
-            null.deviance = nulldev, 
-            iter = iter, 
-            weights = wt, 
+            null.deviance = nulldev,
+            iter = iter,
+            weights = wt,
             prior.weights = weights,
-            df.residual = resdf, 
-            df.null = nulldf, 
-            y = y, 
+            df.residual = resdf,
+            df.null = nulldf,
+            y = y,
             converged = conv,
-            boundary = boundary, 
-            prior.mean = prior.mean, 
+            boundary = boundary,
+            prior.mean = prior.mean,
             prior.scale = prior.scale,
-            prior.df = prior.df, 
-            prior.sd = prior.sd, 
+            prior.df = prior.df,
+            prior.sd = prior.sd,
             dispersion = dispersion)
 }
 
 
 
 
-.bayesglm.fit.initialize.priors <- function (family, prior.scale, prior.scale.for.intercept, nvars, 
+.bayesglm.fit.initialize.priors <- function (family, prior.scale, prior.scale.for.intercept, nvars,
         prior.mean, prior.mean.for.intercept, intercept, prior.df, prior.df.for.intercept) {
     ##### 12.13 ####
     if (is.null(prior.scale)){
@@ -300,7 +300,7 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
             prior.scale <- prior.scale*1.6
         }
     }
-    
+
     if (is.null(prior.scale.for.intercept)){
         prior.scale.for.intercept <- 10
         if (family$link == "probit"){
@@ -308,7 +308,7 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
         }
     }
     ################
-    
+
     if (length(prior.mean) == 1) {
         prior.mean <- rep(prior.mean, nvars)
     }
@@ -317,7 +317,7 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
             prior.mean <- c(prior.mean.for.intercept, prior.mean)
         }
     }
-    
+
     if (length(prior.scale)==1){
         prior.scale <- rep(prior.scale, nvars)
     }
@@ -326,7 +326,7 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
             prior.scale <- c(prior.scale.for.intercept, prior.scale)
         }
     }
-    
+
     if (length(prior.df) == 1) {
         prior.df <- rep(prior.df, nvars)
     }
@@ -335,8 +335,8 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
             prior.df <- c(prior.df.for.intercept, prior.df)
         }
     }
-    
-    list (prior.scale=prior.scale, 
+
+    list (prior.scale=prior.scale,
             prior.scale.for.intercept=prior.scale.for.intercept,
             prior.mean=prior.mean,
             prior.scale=prior.scale,
@@ -348,7 +348,7 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
         if (family$family == "gaussian"){
             prior.scale <- prior.scale * 2 * sd(y)
         }
-        
+
         for (j in 1:nvars) {
             x.obs <- x[, j]
             x.obs <- x.obs[!is.na(x.obs)]
@@ -361,7 +361,7 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
                 x.scale <- 2 * sd(x.obs)
             }
             prior.scale[j] <- prior.scale[j]/x.scale
-            
+
             if (prior.scale[j] < min.prior.scale){
                 prior.scale[j] <- min.prior.scale
                 warning ("prior scale for variable ", j,
@@ -380,7 +380,7 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
     if (intercept & scaled) {
         x[nobs+1,] <- colMeans(x.nobs)
     }
-    
+
     list (x=x, xnames=xnames, x.nobs=x.nobs)
 }
 
@@ -391,11 +391,11 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
     if (is.null(family$valideta)){
         family$valideta <- function(eta) TRUE
     }
-    
+
     if (is.null(family$validmu)){
         family$validmu <- function(mu) TRUE
     }
-    
+
     return (family)
 }
 
@@ -406,32 +406,32 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
     else{
         ynames <- names(y)
     }
-    
+
     if (is.null(weights)){
         weights <- rep.int(1, nobs)
     }
-    
+
     if (is.null(offset)){
         offset <- rep.int(0, nobs)
     }
-    
+
     list (ynames=ynames,
             weights=weights,
             offset=offset)
 }
 
-.bayesglm.fit.loop.setup <- function (etastart, start, nvars, xnames, offset, x, nobs, family, 
+.bayesglm.fit.loop.setup <- function (etastart, start, nvars, xnames, offset, x, nobs, family,
         mustart, eta, weights, conv, prior.scale, y, x.nobs) {
     coefold <- NULL
     if (!is.null(etastart)) {
         eta <- etastart
     } else if (!is.null(start)) {
         if (length(start) != nvars){
-            if(start==0&length(start)==1){ 
+            if(start==0&length(start)==1){
               start <- rep(0, nvars)
               eta <- offset + as.vector(ifelse((NCOL(x) == 1), x.nobs[,1]*start, x.nobs %*% start))
             }else{
-              stop(gettextf("length of 'start' should equal %d and correspond to initial coefs for %s", 
+              stop(gettextf("length of 'start' should equal %d and correspond to initial coefs for %s",
                             nvars, paste(deparse(xnames), collapse = ", ")), domain = NA)
             }
         }else {
@@ -442,7 +442,7 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
     else {
         eta <- family$linkfun(mustart)
     }
-    
+
     mu <- family$linkinv(eta)
     if (!isTRUE(family$validmu(mu) && family$valideta(eta)))
         stop("cannot find valid starting values: please specify some")
@@ -484,7 +484,7 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
     }
     else if (!is.null(start)) {
         coefold <- as.matrix (start)
-        eta <- drop (x.nobs %*% start) + offset 
+        eta <- drop (x.nobs %*% start) + offset
         ## TODO: should be able to drop this. coefold is the original start.
         #coefold <- start
     }
@@ -508,12 +508,12 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
             dev=dev,
             conv=FALSE,
             boundary=FALSE,
-            prior.sd=prior.sd) 
+            prior.sd=prior.sd)
 }
 
 .bayesglm.fit.loop.validateInputs <- function(etastart, start, nvars, xnames) {
     if (is.null(etastart) & !is.null(start) & length(start) != nvars) {
-        stop(gettextf("length of 'start' should equal %d and correspond to initial coefs for %s", 
+        stop(gettextf("length of 'start' should equal %d and correspond to initial coefs for %s",
                         nvars, paste(xnames, collapse = ", ")), domain = NA)
     }
 }
@@ -534,19 +534,19 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
     if (any(state$varmu[state$good] == 0)){
         stop("0s in V(mu)")
     }
-    
+
     if (any(is.na(state$mu.eta.val[state$good]))){
         stop("NAs in d(mu)/d(eta)")
     }
-    
-    if (iter > 1 & abs(state$dev - devold)/(0.1 + abs(state$dev)) <  control$epsilon & 
+
+    if (iter > 1 & abs(state$dev - devold)/(0.1 + abs(state$dev)) <  control$epsilon &
             abs(state$dispersion - dispersionold)/(0.1 + abs(state$dispersion)) < control$epsilon) {
         return (FALSE)
     }
     return (TRUE)
 }
 
-.bayesglm.fit.loop.updateState <- function (state, priors, family, #fortran.call.parameters, 
+.bayesglm.fit.loop.updateState <- function (state, priors, family, #fortran.call.parameters,
         offset, weights,
         y, x, x.nobs, nvars, nobs,
         intercept, scaled, control) {
@@ -556,30 +556,30 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
     w <- sqrt((weights[state$good] * mu.eta.val[state$good]^2)/state$varmu[state$good])
     w.star <- c(w, sqrt(state$dispersion)/state$prior.sd)
     good.star <- c(state$good, rep(TRUE, nvars))
-    fit <- lm.fit(x = as.matrix(x[good.star, ])*w.star, y = z.star*w.star)
+    fit <- lm.wfit(x = as.matrix(x[good.star, ]), w = w.star, y = z.star)
     start <- state$Start
     coefold <- state$Start
 
-    #fit <- .Fortran("dqrls", 
-#            qr = x[good.star, ] * w.star, 
-#            n = sum (good.star), 
-#            p = nvars, 
-#            y = w.star * z.star, 
-#            ny = fortran.call.parameters$ny, 
-#            tol = fortran.call.parameters$tol, 
-#            coefficients = fortran.call.parameters$coefficients, 
-#            residuals = fortran.call.parameters$residuals, 
-#            effects = fortran.call.parameters$effects, 
-#            rank = fortran.call.parameters$rank, 
-#            pivot = fortran.call.parameters$pivot, 
+    #fit <- .Fortran("dqrls",
+#            qr = x[good.star, ] * w.star,
+#            n = sum (good.star),
+#            p = nvars,
+#            y = w.star * z.star,
+#            ny = fortran.call.parameters$ny,
+#            tol = fortran.call.parameters$tol,
+#            coefficients = fortran.call.parameters$coefficients,
+#            residuals = fortran.call.parameters$residuals,
+#            effects = fortran.call.parameters$effects,
+#            rank = fortran.call.parameters$rank,
+#            pivot = fortran.call.parameters$pivot,
 #            qraux = fortran.call.parameters$qraux,
-#            work = fortran.call.parameters$work, 
+#            work = fortran.call.parameters$work,
 #            PACKAGE = "base")
-    
+
 
     state$prior.sd <- priors$scale
     if (all (priors$df==Inf) == FALSE) {
-      colMeans.x <- colMeans (x.nobs)  
+      colMeans.x <- colMeans (x.nobs)
       centered.coefs <- fit$coefficients
       if(NCOL(x.nobs)==1){
         V.coefs <- chol2inv(fit$qr$qr[1:nvars])
@@ -589,7 +589,7 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
       diag.V.coefs <- diag(V.coefs)
       sampling.var <- diag.V.coefs
             # DL: sampling.var[1] <- crossprod(colMeans.x, V.coefs) %*% colMeans.x
-      if(intercept & scaled){      
+      if(intercept & scaled){
         centered.coefs[1] <- sum(fit$coefficients*colMeans.x)
         sampling.var[1] <- crossprod (crossprod(V.coefs, colMeans.x), colMeans.x)
       }
@@ -597,19 +597,19 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
       sd.coef <- sqrt(sd.tmp)
       state$prior.sd[priors$df != Inf] <- sd.coef[priors$df != Inf]
     }
-    
+
     if(NCOL(x.nobs)==1){
       predictions <- x.nobs * fit$coefficients
     }else{
       predictions <- x.nobs %*% fit$coefficients
     }
- 
+
     start[fit$qr$pivot] <- fit$coefficients
 
     if (!(family$family %in% c("poisson", "binomial"))) {
       if (exists ("V.coefs") == FALSE) {
         if(NCOL(x.nobs)==1){
-          V.coefs <- chol2inv(fit$qr$qr[1:nvars])            
+          V.coefs <- chol2inv(fit$qr$qr[1:nvars])
         }else{
           V.coefs <- chol2inv(fit$qr$qr[1:nvars, 1:nvars, drop = FALSE])
         }
@@ -617,15 +617,15 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
       #mse.resid <- mean((w * (z - x.nobs %*% fit$coefficients))^2) ## LOCAL VARIABLE
       #mse.resid <- mean ( (fit$y[1:nobs] - w * predictions)^2)
       ## mse.uncertainty <- mean(diag(x.nobs %*% V.coefs %*% t(x.nobs))) * state$dispersion
-      mse.resid <- mean ( ((z.star*w.star)[1:sum(state$good)] - w * predictions[state$good,])^2)       
+      mse.resid <- mean ( ((z.star*w.star)[1:sum(state$good)] - w * predictions[state$good,])^2)
       mse.uncertainty <- max (0, mean(rowSums(( x.nobs %*% V.coefs ) * x.nobs)) * state$dispersion) #faster  ## LOCAL VARIABLE
       state$dispersion <- mse.resid + mse.uncertainty
     }
-   
+
     state$eta <- drop(predictions)
     state$mu <- family$linkinv(state$eta + offset)
     state$mu.eta.val <- family$mu.eta(state$eta)
-    
+
     dev <- sum (family$dev.resids (y, state$mu, weights))
 
     if (!is.finite (dev) || !isTRUE(family$valideta(state$eta) && family$validmu(state$mu))) {
@@ -636,7 +636,7 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
          warning("step size truncated due to divergence", call. = FALSE)
         } else if (!isTRUE(family$valideta(state$eta) && family$validmu(state$mu))) {
             warning("step size truncated: out of bounds", call. = FALSE)
-        } 
+        }
         ii <- 1
         while (ii <= control$maxit & !is.finite (dev)) {
             ii <- ii + 1
@@ -645,14 +645,14 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
                             drop(x.nobs * start)
                           }else{
                             drop(x.nobs %*% start)
-                          }                       
+                          }
             state$mu <- family$linkinv(state$eta + offset)
             dev <- sum (family$dev.resids (y, state$mu, weights))
         }
         if (ii > control$maxit) {
             stop("inner loop 1; cannot correct step size")
         }
-        
+
         ii <- 1
         while (ii <= control$maxit &  !isTRUE(family$valideta(state$eta) && family$validmu(state$mu))) {
             ii <- ii + 1
@@ -661,14 +661,14 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
                             drop(x.nobs * start)
                           }else{
                             drop(x.nobs %*% start)
-                          }         
+                          }
             state$mu <- family$linkinv(state$eta + offset)
         }
         if (ii > control$maxit) {
             stop("inner loop 2; cannot correct step size")
         }
-        
-        
+
+
         state$boundary <- TRUE
         if (control$trace){
             cat("Step halved: new deviance =", dev, "\n")
@@ -689,7 +689,7 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
             boundary=state$boundary,
             prior.sd=state$prior.sd,
             z=z,
-            w=w) 
+            w=w)
 }
 
 
@@ -726,9 +726,9 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
     }
     residuals <- rep.int(NA, nobs)
     residuals[state$good] <- state$z[state$good] - (state$eta[state$good] - offset[state$good])
-    
+
     state$fit$qr$qr <- as.matrix(state$fit$qr$qr)
-    
+
     nr <- min(sum(state$good), nvars)
     if (nr < nvars) {
       Rmat <- diag(x = 0, nvars)
@@ -748,7 +748,7 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
     dimnames(Rmat) <- list(xnames, xnames)
     list (residuals=residuals,
             Rmat=Rmat,
-            state=state)    
+            state=state)
 }
 
 .bayesglm.fit.loop.printWarnings <- function (Warning, state, family) {
@@ -775,7 +775,7 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
 
 
 .bayesglm.fit.loop.main.ideal <- function (control, x, y, nvars, nobs, weights, offset,
-        intercept, scaled, 
+        intercept, scaled,
         start, etastart, mustart,
         family,
         prior.mean, prior.mean.for.intercept, prior.scale, prior.df, prior.df.for.intercept,
@@ -784,46 +784,46 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
 
     xnames <- dimnames(x)[[2]]
     x.nobs <- x[1:nobs, ,drop=FALSE]
-    
+
     .bayesglm.fit.loop.validateInputs (etastart, start, nvars, dimnames(x)[[2]])
-    
+
     # invalid starting point (should be moved out of here):
     # is.null(start)==false & length(start) != nvars
-    
-    priors <- .bayesglm.fit.loop.initializePriors (prior.mean, prior.mean.for.intercept, prior.scale, prior.df, prior.df.for.intercept)    
-    
+
+    priors <- .bayesglm.fit.loop.initializePriors (prior.mean, prior.mean.for.intercept, prior.scale, prior.df, prior.df.for.intercept)
+
     state <- .bayesglm.fit.loop.initializeState (start, etastart, mustart, offset, x.nobs, var(y), nvars, family, weights, priors$scale, y)
     #core elements of state:
     # good: derived from eta
     # eta
     # x, y, nvars, nobs: invariants
-    
+
     #fortran.call.parameters <- .bayesglm.fit.loop.initialMemoryAllocation (control$epsilon, nvars, sum (state$good))
-    
+
     for (iter in 1:control$maxit) {
         dispersionold <- state$dispersion
         devold <- state$dev
-        state <- .bayesglm.fit.loop.updateState (state, priors, family, #fortran.call.parameters, 
+        state <- .bayesglm.fit.loop.updateState (state, priors, family, #fortran.call.parameters,
                 offset, weights,
                 y, x, x.nobs, nvars, nobs,
-                intercept, scaled, control) 
+                intercept, scaled, control)
         if (control$trace){
             cat("Deviance =", state$dev, "Iterations -", iter, "\n")
         }
-        
+
         if (.bayesglm.fit.loop.validateState(state, family, control, iter, dispersionold, devold) == FALSE) {
             state$conv <- TRUE
             break
         }
         .bayesglm.fit.loop.print(state, priors, family, print.unnormalized.log.posterior, intercept, y)
     }
-    
+
     .bayesglm.fit.loop.printWarnings(Warning, state, family)
     output <- .bayesglm.fit.loop.createAuxillaryItems(state, nvars, nobs, xnames, offset)
     ## residuals=residuals
     ## Rmat=Rmat
     ## state
-    
+
     list (fit=output$state$fit,
             good=output$state$good,
             z=output$state$z,
@@ -877,12 +877,12 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
     resdf <- n.ok - rank
     resdf <- n.ok
     aic.model <- aic(y, n.ok, mu, w, dev) + 2 * rank
-    
+
     list (residuals=residuals,
             mu=mu,
             eta=eta,
-            wt = wt, 
-            weights = w, 
+            wt = wt,
+            weights = w,
             y=y,
             wtdmu=wtdmu,
             nulldev=nulldev,
@@ -894,31 +894,31 @@ bayesglm.fit <- function (x, y, weights = rep(1, nobs), start = NULL,
 }
 
 
-setMethod("print", signature(x = "bayesglm"), 
+setMethod("print", signature(x = "bayesglm"),
     function(x, digits=2) display(object=x, digits=digits))
 
-setMethod("show", signature(object = "bayesglm"), 
+setMethod("show", signature(object = "bayesglm"),
     function(object) display(object, digits=2))
 
-predict.bayesglm <- function (object, newdata = NULL, type = c("link", "response", 
-    "terms"), se.fit = FALSE, dispersion = NULL, terms = NULL, 
-    na.action = na.pass, ...) 
+predict.bayesglm <- function (object, newdata = NULL, type = c("link", "response",
+    "terms"), se.fit = FALSE, dispersion = NULL, terms = NULL,
+    na.action = na.pass, ...)
 {
     type <- match.arg(type)
     na.act <- object$na.action
     object$na.action <- NULL
     if (!se.fit) {
         if (missing(newdata)) {
-            pred <- switch(type, link = object$linear.predictors, 
-                response = object$fitted.values, terms = predictLM(object, 
-                  se.fit = se.fit, scale = 1, type = "terms", 
+            pred <- switch(type, link = object$linear.predictors,
+                response = object$fitted.values, terms = predictLM(object,
+                  se.fit = se.fit, scale = 1, type = "terms",
                   terms = terms))
-            if (!is.null(na.act)) 
+            if (!is.null(na.act))
                 pred <- napredict(na.act, pred)
         }
         else {
-            pred <- predictLM(object, newdata, se.fit, scale = 1, 
-                type = ifelse(type == "link", "response", type), 
+            pred <- predictLM(object, newdata, se.fit, scale = 1,
+                type = ifelse(type == "link", "response", type),
                 terms = terms, na.action = na.action)
             switch(type, response = {
                 pred <- family(object)$linkinv(pred)
@@ -926,13 +926,13 @@ predict.bayesglm <- function (object, newdata = NULL, type = c("link", "response
         }
     }
     else {
-        if (inherits(object, "survreg")) 
+        if (inherits(object, "survreg"))
             dispersion <- 1
-        if (is.null(dispersion) || dispersion == 0) 
+        if (is.null(dispersion) || dispersion == 0)
             dispersion <- summary(object, dispersion = dispersion)$dispersion
         residual.scale <- as.vector(sqrt(dispersion))
-        pred <- predictLM(object, newdata, se.fit, scale = residual.scale, 
-            type = ifelse(type == "link", "response", type), 
+        pred <- predictLM(object, newdata, se.fit, scale = residual.scale,
+            type = ifelse(type == "link", "response", type),
             terms = terms, na.action = na.action)
         fit <- pred$fit
         se.fit <- pred$se.fit
@@ -949,15 +949,15 @@ predict.bayesglm <- function (object, newdata = NULL, type = c("link", "response
     pred
 }
 
-predictLM <- function (object, newdata, se.fit = FALSE, scale = NULL, df = Inf, 
-    interval = c("none", "confidence", "prediction"), level = 0.95, 
-    type = c("response", "terms"), terms = NULL, na.action = na.pass, 
-    pred.var = res.var/weights, weights = 1, ...) 
+predictLM <- function (object, newdata, se.fit = FALSE, scale = NULL, df = Inf,
+    interval = c("none", "confidence", "prediction"), level = 0.95,
+    type = c("response", "terms"), terms = NULL, na.action = na.pass,
+    pred.var = res.var/weights, weights = 1, ...)
 {
     tt <- terms(object)
     keep.order <- object$keep.order
     drop.baseline <- object$drop.baseline
-    if (!inherits(object, "lm")) 
+    if (!inherits(object, "lm"))
         warning("calling predict.lm(<fake-lm-object>) ...")
     if (missing(newdata) || is.null(newdata)) {
         mm <- X <- model.matrix(object)
@@ -966,33 +966,33 @@ predictLM <- function (object, newdata, se.fit = FALSE, scale = NULL, df = Inf,
     }
     else {
         Terms <- delete.response(tt)
-        m <- model.frame(Terms, newdata, na.action = na.action, 
+        m <- model.frame(Terms, newdata, na.action = na.action,
             xlev = object$xlevels)
-        if (!is.null(cl <- attr(Terms, "dataClasses"))) 
+        if (!is.null(cl <- attr(Terms, "dataClasses")))
             .checkMFClasses(cl, m)
         X <- model.matrixBayes(Terms, m, contrasts.arg = object$contrasts, keep.order = keep.order, drop.baseline = drop.baseline)
         offset <- rep(0, nrow(X))
-        if (!is.null(off.num <- attr(tt, "offset"))) 
-            for (i in off.num) offset <- offset + eval(attr(tt, 
+        if (!is.null(off.num <- attr(tt, "offset")))
+            for (i in off.num) offset <- offset + eval(attr(tt,
                 "variables")[[i + 1]], newdata)
-        if (!is.null(object$call$offset)) 
+        if (!is.null(object$call$offset))
             offset <- offset + eval(object$call$offset, newdata)
         mmDone <- FALSE
     }
     n <- length(object$residuals)
     p <- object$rank
     p1 <- seq_len(p)
-    piv <- if (p) 
+    piv <- if (p)
         getQr(object)$pivot[p1]
-    if (p < ncol(X) && !(missing(newdata) || is.null(newdata))) 
+    if (p < ncol(X) && !(missing(newdata) || is.null(newdata)))
         warning("prediction from a rank-deficient fit may be misleading")
     beta <- object$coefficients
     predictor <- drop(X[, piv, drop = FALSE] %*% beta[piv])
-    if (!is.null(offset)) 
+    if (!is.null(offset))
         predictor <- predictor + offset
     interval <- match.arg(interval)
     if (interval == "prediction") {
-        if (missing(newdata)) 
+        if (missing(newdata))
             warning("Predictions on current data refer to _future_ responses\n")
         if (missing(newdata) && missing(weights)) {
             w <- .weights.default(object)
@@ -1001,13 +1001,13 @@ predictLM <- function (object, newdata, se.fit = FALSE, scale = NULL, df = Inf,
                 warning("Assuming prediction variance inversely proportional to weights used for fitting\n")
             }
         }
-        if (!missing(newdata) && missing(weights) && !is.null(object$weights) && 
-            missing(pred.var)) 
+        if (!missing(newdata) && missing(weights) && !is.null(object$weights) &&
+            missing(pred.var))
             warning("Assuming constant prediction variance even though model fit is weighted\n")
         if (inherits(weights, "formula")) {
-            if (length(weights) != 2L) 
+            if (length(weights) != 2L)
                 stop("'weights' as formula should be one-sided")
-            d <- if (missing(newdata) || is.null(newdata)) 
+            d <- if (missing(newdata) || is.null(newdata))
                 model.frame(object)
             else newdata
             weights <- eval(weights[[2L]], d, environment(weights))
@@ -1025,7 +1025,7 @@ predictLM <- function (object, newdata, se.fit = FALSE, scale = NULL, df = Inf,
         else scale^2
         if (type != "terms") {
             if (p > 0) {
-                XRinv <- if (missing(newdata) && is.null(w)) 
+                XRinv <- if (missing(newdata) && is.null(w))
                   qr.Q(getQr(object))[, p1, drop = FALSE]
                 else X[, piv] %*% qr.solve(qr.R(getQr(object))[p1, p1])
                 ip <- drop(XRinv^2 %*% rep(res.var, p))
@@ -1041,7 +1041,7 @@ predictLM <- function (object, newdata, se.fit = FALSE, scale = NULL, df = Inf,
         aa <- attr(mm, "assign")
         ll <- attr(tt, "term.labels")
         hasintercept <- attr(tt, "intercept") > 0L
-        if (hasintercept) 
+        if (hasintercept)
             ll <- c("(Intercept)", ll)
         aaa <- factor(aa, labels = ll)
         asgn <- split(order(aa), aaa)
@@ -1063,7 +1063,7 @@ predictLM <- function (object, newdata, se.fit = FALSE, scale = NULL, df = Inf,
                 dimnames(ip) <- list(rownames(X), names(asgn))
                 Rinv <- qr.solve(qr.R(getQr(object))[p1, p1])
             }
-            if (hasintercept) 
+            if (hasintercept)
                 X <- sweep(X, 2L, avx, check.margin = FALSE)
             unpiv <- rep.int(0L, NCOL(X))
             unpiv[piv] <- p1
@@ -1071,40 +1071,40 @@ predictLM <- function (object, newdata, se.fit = FALSE, scale = NULL, df = Inf,
                 iipiv <- asgn[[i]]
                 ii <- unpiv[iipiv]
                 iipiv[ii == 0L] <- 0L
-                predictor[, i] <- if (any(iipiv > 0L)) 
+                predictor[, i] <- if (any(iipiv > 0L))
                   X[, iipiv, drop = FALSE] %*% beta[iipiv]
                 else 0
-                if (se.fit || interval != "none") 
-                  ip[, i] <- if (any(iipiv > 0L)) 
-                    as.matrix(X[, iipiv, drop = FALSE] %*% Rinv[ii, 
-                      , drop = FALSE])^2 %*% rep.int(res.var, 
+                if (se.fit || interval != "none")
+                  ip[, i] <- if (any(iipiv > 0L))
+                    as.matrix(X[, iipiv, drop = FALSE] %*% Rinv[ii,
+                      , drop = FALSE])^2 %*% rep.int(res.var,
                       p)
                   else 0
             }
             if (!is.null(terms)) {
                 predictor <- predictor[, terms, drop = FALSE]
-                if (se.fit) 
+                if (se.fit)
                   ip <- ip[, terms, drop = FALSE]
             }
         }
         else {
             predictor <- ip <- matrix(0, n, 0L)
         }
-        attr(predictor, "constant") <- if (hasintercept) 
+        attr(predictor, "constant") <- if (hasintercept)
             termsconst
         else 0
     }
     if (interval != "none") {
         tfrac <- qt((1 - level)/2, df)
-        hwid <- tfrac * switch(interval, confidence = sqrt(ip), 
+        hwid <- tfrac * switch(interval, confidence = sqrt(ip),
             prediction = sqrt(ip + pred.var))
         if (type != "terms") {
-            predictor <- cbind(predictor, predictor + hwid %o% 
+            predictor <- cbind(predictor, predictor + hwid %o%
                 c(1, -1))
             colnames(predictor) <- c("fit", "lwr", "upr")
         }
         else {
-            if (!is.null(terms)) 
+            if (!is.null(terms))
                 hwid <- hwid[, terms, drop = FALSE]
             lwr <- predictor + hwid
             upr <- predictor - hwid
@@ -1112,12 +1112,12 @@ predictLM <- function (object, newdata, se.fit = FALSE, scale = NULL, df = Inf,
     }
     if (se.fit || interval != "none") {
         se <- sqrt(ip)
-        if (type == "terms" && !is.null(terms) && !se.fit) 
+        if (type == "terms" && !is.null(terms) && !se.fit)
             se <- se[, terms, drop = FALSE]
     }
     if (missing(newdata) && !is.null(na.act <- object$na.action)) {
         predictor <- napredict(na.act, predictor)
-        if (se.fit) 
+        if (se.fit)
             se <- napredict(na.act, se)
     }
     if (type == "terms" && interval != "none") {
@@ -1125,10 +1125,10 @@ predictLM <- function (object, newdata, se.fit = FALSE, scale = NULL, df = Inf,
             lwr <- napredict(na.act, lwr)
             upr <- napredict(na.act, upr)
         }
-        list(fit = predictor, se.fit = se, lwr = lwr, upr = upr, 
+        list(fit = predictor, se.fit = se, lwr = lwr, upr = upr,
             df = df, residual.scale = sqrt(res.var))
     }
-    else if (se.fit) 
+    else if (se.fit)
         list(fit = predictor, se.fit = se, df = df, residual.scale = sqrt(res.var))
     else predictor
 }
@@ -1136,7 +1136,7 @@ predictLM <- function (object, newdata, se.fit = FALSE, scale = NULL, df = Inf,
 
 
 getQr <- function(x, ...){
-  if (is.null(r <- x$qr)) 
+  if (is.null(r <- x$qr))
         stop("lm object does not have a proper 'qr' component.\n Rank zero or should not have used lm(.., qr=FALSE).")
   r
 }
